.. HighTea documentation master file, created by
   sphinx-quickstart on Tue Dec  1 19:56:32 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Documentation for `hightea-plotting`
====================================

Supporting collection of classes and functions for the HighTEA project, that aims
to facilitate data visualisation in high-energy physics precision studies.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

Plotting procedures
===================

.. automodule:: hightea.plotting.plotting
    :members:

Run class
===============

.. automodule:: hightea.plotting.run
    :members:

Extra loaders
=============

.. automodule:: hightea.plotting.stripper
    :members:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
